Make the do_complete() function not get called until the DO actually is
compelete, which bascially means when used with the multi interface
diff --git a/lib/url.c b/lib/url.c
index 7fee3da..0415d51 100644
--- a/lib/url.c
+++ b/lib/url.c
@@ -4575,8 +4575,8 @@
       }
     }
 
-    if(result == CURLE_OK)
-      /* pre readwrite must be called after the protocol-specific DO function */
+    if((result == CURLE_OK) && *done)
+      /* do_complete must be called after the protocol-specific DO function */
       do_complete(conn);
   }
   return result;
@@ -4589,6 +4589,10 @@
   if(conn->handler->do_more)
     result = conn->handler->do_more(conn);
 
+  if(result == CURLE_OK)
+    /* do_complete must be called after the protocol-specific DO function */
+    do_complete(conn);
+
   return result;
 }